Class: LogtoError::SessionMismatchError
- Inherits:
-
LogtoError
- Object
- LogtoError
- LogtoError::SessionMismatchError
- Defined in:
- lib/logto/client/errors.rb
Overview
Raise when the session is found but the parameters are mismatched.
Raise when the session is found but the parameters are mismatched.