Class: LogtoError::SessionNotFoundError
- Inherits:
-
LogtoError
- Object
- LogtoError
- LogtoError::SessionNotFoundError
- Defined in:
- lib/logto/client/errors.rb
Overview
Raise when the session is not found in the storage.
Raise when the session is not found in the storage.